This package was written as part of a homework assignment for CMC CSCI046: Data Structures and Algorithms. Use at your own risk!  

The package implements multiple types of data structures, including the following:   

- Generator objects (implemented with range and fibonacci)   
- Binary Trees    
- Binary Search Trees    
- AVL Trees    
- Heap Binary Trees   
